==> de.bsvrz.buv.plugin.dobj.source_4.0.0.201905071350.jar: de/bsvrz/buv/plugin/dobj/actions/ToggleAntiKollisionsAlgorithmusAction.java <==
/*
 * Rahmenwerk-Plug-in "Darstellungsobjekte"
 * Copyright (C) 2018 BitCtrl Systems GmbH
 *
 * This program is free software; you can redistribute it and/or modify it under
 * the terms of the GNU General Public License as published by the Free Software
 * Foundation; either version 3 of the License, or (at your option) any later
 * version.
 *
 * This program is distributed in the hope that it will be useful, but WITHOUT
 * ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS
 * FOR A PARTICULAR PURPOSE. See the GNU General Public License for more
 * details.
 *
 * You should have received a copy of the GNU General Public License along with
 * this program; if not, write to the Free Software Foundation, Inc., 51
 * Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
 *
 * Contact Information:
 * BitCtrl Systems GmbH
 * Weissenfelser Strasse 67
 * 04229 Leipzig
 * Phone: +49 341-490670
 * mailto: info@bitctrl.de
 */
package de.bsvrz.buv.plugin.dobj.actions;

import org.eclipse.gef.EditPart;
import org.eclipse.gef.GraphicalViewer;
import org.eclipse.gef.Request;
import org.eclipse.jface.action.IAction;
import org.eclipse.ui.IWorkbenchPart;

import de.bsvrz.buv.plugin.dobj.internal.DobjMessages;
import de.bsvrz.buv.plugin.dobj.requests.KollisionsAlgorithmusRequest;
import de.bsvrz.buv.plugin.dobj.util.DobjIcons;

/**
 * Schaltet den Antikollisionsalgorithmus ein und aus.
 *
 * @author BitCtrl Systems GmbH, Schumann
 *
 */
public class ToggleAntiKollisionsAlgorithmusAction extends DobjWorkbenchPartAction {

	/**
	 * Initialisiert die Action.
	 *
	 * @param part
	 *            der Workbench Part mit dem die Action arbeiten soll.
	 */
	public ToggleAntiKollisionsAlgorithmusAction(final IWorkbenchPart part) {
		super(part, IAction.AS_CHECK_BOX);

		setText(DobjMessages.ToggleAntiKollisionsAlgorithmus_Label);
		setToolTipText(DobjMessages.ToggleAntiKollisionsAlgorithmus_Tooltip);
		setId(DobjActionFactory.TOGGLE_ANTI_KOLLISIONS_ALGORITHMUS.getCommandId());
		setActionDefinitionId(DobjActionFactory.TOGGLE_ANTI_KOLLISIONS_ALGORITHMUS.getCommandId());
		setImageDescriptor(DobjIcons.ActionToggleAntikollisionsAlgorithmus.getImageDescriptor());
		setChecked(true);
	}

	@Override
	public void run() {
		final GraphicalViewer viewer = getViewer();

		final Request req = new KollisionsAlgorithmusRequest(isChecked());
		for (final Object e : viewer.getEditPartRegistry().values()) {
			final EditPart editPart = (EditPart) e;
			editPart.performRequest(req);
		}
	}

}

==> de.bsvrz.buv.plugin.dobj.source_4.5.0.202510170820.jar: de/bsvrz/buv/plugin/dobj/actions/ToggleAntiKollisionsAlgorithmusAction.java <==
/*
 * Rahmenwerk-Plug-in "Darstellungsobjekte"
 * Copyright (C) 2023 BitCtrl Systems GmbH
 *
 * This program is free software; you can redistribute it and/or modify it under
 * the terms of the GNU General Public License as published by the Free Software
 * Foundation; either version 3 of the License, or (at your option) any later
 * version.
 *
 * This program is distributed in the hope that it will be useful, but WITHOUT
 * ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS
 * FOR A PARTICULAR PURPOSE. See the GNU General Public License for more
 * details.
 *
 * You should have received a copy of the GNU General Public License along with
 * this program; if not, write to the Free Software Foundation, Inc., 51
 * Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
 *
 * Contact Information:
 * BitCtrl Systems GmbH
 * Weissenfelser Strasse 67
 * 04229 Leipzig
 * Phone: +49 341-490670
 * mailto: info@bitctrl.de
 */
package de.bsvrz.buv.plugin.dobj.actions;

import org.eclipse.gef.EditPart;
import org.eclipse.gef.GraphicalViewer;
import org.eclipse.gef.Request;
import org.eclipse.jface.action.IAction;
import org.eclipse.ui.IWorkbenchPart;

import de.bsvrz.buv.plugin.dobj.internal.DobjMessages;
import de.bsvrz.buv.plugin.dobj.requests.KollisionsAlgorithmusRequest;
import de.bsvrz.buv.plugin.dobj.util.DobjIcons;

/**
 * Schaltet den Antikollisionsalgorithmus ein und aus.
 *
 * @author BitCtrl Systems GmbH, Schumann
 *
 */
public class ToggleAntiKollisionsAlgorithmusAction extends DobjWorkbenchPartAction {

	/**
	 * Initialisiert die Action.
	 *
	 * @param part
	 *            der Workbench Part mit dem die Action arbeiten soll.
	 */
	public ToggleAntiKollisionsAlgorithmusAction(final IWorkbenchPart part) {
		super(part, IAction.AS_CHECK_BOX);

		setText(DobjMessages.toggleAntiKollisionsAlgorithmusLabel);
		setToolTipText(DobjMessages.toggleAntiKollisionsAlgorithmusTooltip);
		setId(DobjActionFactory.TOGGLE_ANTI_KOLLISIONS_ALGORITHMUS.getCommandId());
		setActionDefinitionId(DobjActionFactory.TOGGLE_ANTI_KOLLISIONS_ALGORITHMUS.getCommandId());
		setImageDescriptor(DobjIcons.ActionToggleAntikollisionsAlgorithmus.getImageDescriptor());
		setChecked(true);
	}

	@Override
	public void run() {
		final GraphicalViewer viewer = getViewer();

		final Request req = new KollisionsAlgorithmusRequest(isChecked());
		for (final Object e : viewer.getEditPartRegistry().values()) {
			final EditPart editPart = (EditPart) e;
			editPart.performRequest(req);
		}
	}

}
